@@ -1,9 +1,10 @@
+import importlib.metadata
+import importlib.resources
 import json
 import os
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Any, Dict, List, Optional, Union
 
-import pkg_resources
 import requests
 import yaml
 from dotenv import load_dotenv
@@ -24,6 +25,8 @@ class Linter:
         links (bool, optional): A boolean value indicating whether to validate links. Defaults to False.
         recursive (bool, optional): A boolean value indicating whether to perform recursive validation. Defaults to False.
         max_depth (Optional[int], optional): An optional integer indicating the maximum depth to validate recursively. Defaults to None.
+        assets_open_urls (bool): Whether to open assets URLs when validating assets. Defaults to True.
+        headers (dict): HTTP headers to include in the requests.
 
     Attributes:
         data (dict): A dictionary representing the STAC JSON file.
@@ -125,6 +128,8 @@ class Linter:
     links: bool = False
     recursive: bool = False
     max_depth: Optional[int] = None
+    assets_open_urls: bool = True
+    headers: dict = field(default_factory=dict)
 
     def __post_init__(self):
         self.data = self.load_data(self.item)
@@ -134,7 +139,9 @@ class Linter:
             self.message["asset_type"] if "asset_type" in self.message else ""
         )
         self.version = self.message["version"] if "version" in self.message else ""
-        self.validator_version = pkg_resources.require("stac-validator")[0].version
+        self.validator_version = importlib.metadata.distribution(
+            "stac-validator"
+        ).version
         self.validate_all = self.recursive_validation(self.item)
         self.valid_stac = self.message["valid_stac"]
         self.error_type = self.check_error_type()
@@ -185,7 +192,9 @@ class Linter:
             with open(default_config_file) as f:
                 default_config = yaml.load(f, Loader=yaml.FullLoader)
         else:
-            with pkg_resources.resource_stream(__name__, "stac-check.config.yml") as f:
+            with importlib.resources.open_text(
+                "stac_check", "stac-check.config.yml"
+            ) as f:
                 default_config = yaml.load(f, Loader=yaml.FullLoader)
         if config_file:
             with open(config_file) as f:
@@ -231,7 +240,7 @@ class Linter:
 
         if isinstance(file, str):
             if is_valid_url(file):
-                resp = requests.get(file)
+                resp = requests.get(file, headers=self.headers)
                 data = resp.json()
             else:
                 with open(file) as json_file:
@@ -255,10 +264,18 @@ class Linter:
             ValueError: If `file` is not a valid file path or STAC dictionary.
         """
         if isinstance(file, str):
-            stac = StacValidate(file, links=self.links, assets=self.assets)
+            stac = StacValidate(
+                file,
+                links=self.links,
+                assets=self.assets,
+                assets_open_urls=self.assets_open_urls,
+                headers=self.headers,
+            )
             stac.run()
         elif isinstance(file, dict):
-            stac = StacValidate()
+            stac = StacValidate(
+                assets_open_urls=self.assets_open_urls, headers=self.headers
+            )
             stac.validate_dict(file)
         else:
             raise ValueError("Input must be a file path or STAC dictionary.")
@@ -279,10 +296,21 @@ class Linter:
         """
         if self.recursive:
             if isinstance(file, str):
-                stac = StacValidate(file, recursive=True, max_depth=self.max_depth)
+                stac = StacValidate(
+                    file,
+                    recursive=True,
+                    max_depth=self.max_depth,
+                    assets_open_urls=self.assets_open_urls,
+                    headers=self.headers,
+                )
                 stac.run()
             else:
-                stac = StacValidate(recursive=True, max_depth=self.max_depth)
+                stac = StacValidate(
+                    recursive=True,
+                    max_depth=self.max_depth,
+                    assets_open_urls=self.assets_open_urls,
+                    headers=self.headers,
+                )
                 stac.validate_dict(file)
             return stac.message
         else:
@@ -294,10 +322,10 @@ class Linter:
         Returns:
             A string containing a message for users to update their STAC version.
         """
-        if self.version != "1.0.0":
-            return f"Please upgrade from version {self.version} to version 1.0.0!"
+        if self.version != "1.1.0":
+            return f"Please upgrade from version {self.version} to version 1.1.0!"
         else:
-            return "Thanks for using STAC version 1.0.0!"
+            return "Thanks for using STAC version 1.1.0!"
 
     def check_links_assets(
         self, num_links: int, url_type: str, format_type: str
